Model - agents API reference (0.0.10)

Hide navigation sidebar
Hide table of contents sidebar
Skip to content
Back to top
View this page
Toggle table of contents sidebar

# Model

class inmydata.ConversationalData.Model(value)

  Bases: `Enum`

  Enum representing the model to use when answering the question.

  gpt4

    OpenAI’s gpt4 model.

  o3mini

    OpenAI’s o3mini model, which is a smaller and more efficient version.

  gpt4 = 0
  o3mini = 1